'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _raf = require('raf');

var _raf2 = _interopRequireDefault(_raf);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class NavBackground extends _react2.default.Component {
  constructor(props) {
    super(props);

    this.state = {
      isOpaque: this.props.isOpaque,
      isOpen: this.props.isOpen,
      backgroundOpacity: 0.9
    };
  }

  componentDidMount() {
    window.addEventListener('scroll', () => {
      if (this.RafId) return;

      this.RafId = (0, _raf2.default)(() => {
        if (this.props.isOpen) {
          this.RafId = undefined;
          return;
        }

        const y = window.scrollY || window.pageYOffset;
        const { isOpaque } = this.state;

        if (y >= 50 && !isOpaque) {
          this.setState({ isOpaque: true });
        } else if (!this.props.isOpaque && y < 50 && isOpaque) {
          this.setState({ isOpaque: false });
        }

        this.RafId = undefined;
      });
    });
  }

  componentWillReceiveProps(props) {
    const obj = {};

    if (props.isOpen) {
      obj.isOpen = props.isOpen;
    }
    if (props.isOpaque) {
      const y = window.scrollY || window.pageYOffset;
      obj.isOpaque = y < 50 ? props.isOpaque : true;
    }

    this.setState(obj);

    if (!props.isOpen) return;

    const listener = this.hasTouch ? 'touchend' : 'mouseup';
    const setActiveSection = this.props.setActiveSection;

    window.addEventListener(listener, function onWindowPress(e) {
      let el = e.target;
      let toTrigger = true;

      while (el) {
        if (/nav/.test(el.className)) {
          toTrigger = false;
          break;
        }

        el = el.parentNode;
      }

      if (toTrigger) {
        setActiveSection(-1);
        window.removeEventListener(listener, onWindowPress);
      }
    });
  }

  render() {
    let classnames = 'nav-background flex flex--center-x';
    if (this.props.isOpen) classnames += ' nav-background--open';
    if (this.state.isOpaque) classnames += ' nav-background--opaque';
    return _react2.default.createElement(
      'div',
      { className: classnames },
      this.props.children
    );
  }
}

exports.default = NavBackground;
const { node, bool, func } = _react2.default.PropTypes;

NavBackground.propTypes = {
  children: node,
  isOpaque: bool,
  isOpen: bool,
  setActiveSection: func.isRequired
};