'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _velocityReact = require('velocity-react');

var _section = require('./section');

var _section2 = _interopRequireDefault(_section);

var _navIcons = require('../nav-icons');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class MiddlePanel extends _react2.default.Component {
  constructor(props) {
    super(props);

    this.animation = {
      'closed': {
        display: 'none',
        opacity: 0
      },
      'open': {
        opacity: 1
      }
    };

    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuart'
    };

    this.state = {
      isMobile: this.props.isMobile,
      animation: 'closed',
      activeSection: this.props.activeSection
    };

    this.onToggle = this.onToggle.bind(this);
  }

  componentWillReceiveProps(props) {
    this.setState({
      activeSection: props.activeSection,
      isMobile: props.isMobile
    });
  }

  onTabSelect(i, e) {
    e.preventDefault();

    if (this.state.activeSection === i) {
      i = -1;
    }

    this.props.setActiveSection(i);
    this.setState({ activeSection: i });
  }

  onToggle(i) {
    this.props.toggle();
    this.setState({
      animation: this.state.animation === 'closed' ? 'open' : 'closed'
    });
  }

  render() {
    const { sections, logoLink, logoUrl, tagline } = this.props;
    const { isMobile, activeSection } = this.state;

    return _react2.default.createElement(
      'div',
      { className: 'nav-panel-middle' },
      _react2.default.createElement(
        'ul',
        {
          className: 'nav-panel-middle__ul flex flex--space-between flex--wrap' },
        _react2.default.createElement(
          'a',
          { href: logoLink, className: 'flex flex--center-y' },
          _react2.default.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__logo' },
            _react2.default.createElement('img', {
              className: 'nav-panel-middle__logo-img',
              src: logoUrl })
          ),
          _react2.default.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__tagline-container' },
            _react2.default.createElement(
              'p',
              { className: 'nav-panel-middle__tagline' },
              tagline
            )
          )
        ),
        _react2.default.createElement(
          _velocityReact.VelocityComponent,
          _extends({}, this.velocityConfig, {
            animation: isMobile ? this.animation[this.state.animation] : this.animation['open'] }),
          _react2.default.createElement(
            'div',
            {
              className: 'flex flex--center-all flex--wrap',
              style: { display: isMobile ? 'none' : 'inherit' } },
            sections.map((section, i) => _react2.default.createElement(_section2.default, _extends({
              key: i,
              className: `nav-panel-middle__li nav-panel-middle__btn ${ activeSection === i ? 'nav-panel-middle__li--active' : '' }`,
              handler: this.onTabSelect.bind(this, i)
            }, section)))
          )
        ),
        _react2.default.createElement(
          'li',
          {
            onClick: this.onToggle,
            className: 'nav-panel-middle__hamburger' },
          _react2.default.createElement('button', { dangerouslySetInnerHTML: { __html: _navIcons.hamburgerIcon } })
        )
      )
    );
  }
}

exports.default = MiddlePanel;
const { func, number, bool, string, array } = _react2.default.PropTypes;

MiddlePanel.propTypes = {
  setActiveSection: func.isRequired,
  toggle: func.isRequired,
  activeSection: number,
  isMobile: bool.isRequired,
  sections: array,
  logoUrl: string,
  logoLink: string,
  tagline: string
};

MiddlePanel.defaultProps = {
  logoLink: '/',
  tagline: 'For Giant Ideas',
  activeSection: -1
};