'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _raf = require('raf');

var _raf2 = _interopRequireDefault(_raf);

var _panelTop = require('./components/panel-top');

var _panelTop2 = _interopRequireDefault(_panelTop);

var _panelMiddle = require('./components/panel-middle');

var _panelMiddle2 = _interopRequireDefault(_panelMiddle);

var _panelBottom = require('./components/panel-bottom');

var _panelBottom2 = _interopRequireDefault(_panelBottom);

var _background = require('./components/background');

var _background2 = _interopRequireDefault(_background);

var _environments = require('./components/environments');

var _environments2 = _interopRequireDefault(_environments);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Nav extends _react2.default.Component {
  constructor(props) {
    super(props);

    this.state = {
      isMobile: false,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    };

    this.toggle = this.toggle.bind(this);
    this.setActiveSection = this.setActiveSection.bind(this);
  }

  componentDidMount() {
    this.setState({ isMobile: window.innerWidth <= this.state.breakpoint });

    window.addEventListener('resize', () => {
      if (this.rafId) return;

      this.rafId = (0, _raf2.default)(() => {
        const { isMobile, breakpoint } = this.state;
        const { innerWidth } = window;

        if (isMobile && innerWidth > breakpoint) {
          this.setState({ isMobile: false, isOpen: false, activeSection: -1 });
          document.body.classList.toggle('no-scroll', false);
        } else if (!isMobile && innerWidth <= breakpoint) {
          this.setState({ isMobile: true, activeSection: -1 });
        }

        this.rafId = undefined;
      });
    });
  }

  setActiveSection(activeSection) {
    this.setState({ activeSection });
  }

  toggle(isOpen) {
    isOpen = isOpen || !this.state.isOpen;

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen);
    }

    this.setState({ isOpen });
  }

  render() {
    const { isOpen, activeSection } = this.state;
    const props = Object.assign({}, this.props, _environments2.default[this.props.environment]);

    return _react2.default.createElement(
      'nav',
      { className: 'nav-panel flex flex--center-y flex--wrap' },
      _react2.default.createElement(_panelTop2.default, {
        downloadUrl: props.downloadUrl,
        downloadJmpValue: props.downloadJmpValue,
        includeSearch: props.includeSearch,
        host: props.environment === 'com' ? '' : 'https://www.mongodb.com',
        sections: props.topSections,
        searchUrl: props.searchUrl,
        contactUrl: props.contactUrl }),
      _react2.default.createElement(_panelMiddle2.default, _extends({}, this.state, {
        logoUrl: props.logoUrl,
        tagline: props.tagline,
        logoLink: props.logoLink,
        sections: props.sections,
        toggle: this.toggle,
        setActiveSection: this.setActiveSection })),
      _react2.default.createElement(
        _background2.default,
        {
          isMobile: this.state.isMobile,
          setActiveSection: this.setActiveSection,
          isOpaque: isOpen || activeSection !== -1 || props.isOpaque,
          isOpen: isOpen || activeSection !== -1 },
        _react2.default.createElement(_panelBottom2.default, _extends({}, this.state, {
          midSections: props.sections,
          sections: props.subsections }))
      )
    );
  }
}

exports.default = Nav;
const { bool, string, array } = _react2.default.PropTypes;

Nav.propTypes = {
  topSections: array,
  sections: array,
  subsections: array,

  isOpaque: bool,
  includeSearch: bool,

  environment: string,
  searchUrl: string,
  contactUrl: string,
  downloadUrl: string,
  downloadJmpValue: string,
  logoUrl: string,
  logoLink: string,
  tagline: string
};

Nav.defaultProps = {
  environment: 'com'
};