import React from 'react'
import { VelocityComponent } from 'velocity-react'
import Section from './section'
import { hamburgerIcon } from '../nav-icons'

export default class MiddlePanel extends React.Component {
  constructor (props) {
    super(props)

    this.animation = {
      'closed': {
        display: 'none',
        opacity: 0
      },
      'open': {
        opacity: 1
      }
    }

    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuart'
    }

    this.state = {
      isMobile: this.props.isMobile,
      animation: 'closed',
      activeSection: this.props.activeSection
    }

    this.onToggle = this.onToggle.bind(this)
  }

  componentWillReceiveProps (props) {
    this.setState({
      activeSection: props.activeSection,
      isMobile: props.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })
  }

  onToggle (i) {
    this.props.toggle()
    this.setState({
      animation: this.state.animation === 'closed'
        ? 'open'
        : 'closed'
    })
  }

  render () {
    const { sections, logoLink, logoUrl, tagline } = this.props
    const { isMobile, activeSection } = this.state

    return (
      <div className='nav-panel-middle'>
        <ul
          className='nav-panel-middle__ul flex flex--space-between flex--wrap'>
          <a href={ logoLink } className='flex flex--center-y'>
            <li className='nav-panel-middle__li nav-panel-middle__logo'>
              <img
                className='nav-panel-middle__logo-img'
                src={ logoUrl } />
            </li>
            <li className='nav-panel-middle__li nav-panel-middle__tagline-container'>
              <p className='nav-panel-middle__tagline'>{ tagline }</p>
            </li>
          </a>
          <VelocityComponent
            { ...this.velocityConfig }
            animation={ isMobile
              ? this.animation[this.state.animation]
              : this.animation['open']
            }>
            <div
              className='flex flex--center-all flex--wrap'
              style={{ display: isMobile ? 'none' : 'inherit' }}>
              { sections.map((section, i) =>
                <Section
                  key={ i }
                  className={ `nav-panel-middle__li nav-panel-middle__btn ${ activeSection === i ? 'nav-panel-middle__li--active' : '' }` }
                  handler={ this.onTabSelect.bind(this, i) }
                  { ...section } />
              ) }
            </div>
          </VelocityComponent>
          <li
            onClick={ this.onToggle }
            className='nav-panel-middle__hamburger'>
            <button dangerouslySetInnerHTML={{ __html: hamburgerIcon }} />
          </li>
        </ul>
      </div>
    )
  }
}

const { func, number, bool, string, array } = React.PropTypes

MiddlePanel.propTypes = {
  setActiveSection: func.isRequired,
  toggle: func.isRequired,
  activeSection: number,
  isMobile: bool.isRequired,
  sections: array,
  logoUrl: string,
  logoLink: string,
  tagline: string
}

MiddlePanel.defaultProps = {
  logoLink: '/',
  tagline: 'For Giant Ideas',
  activeSection: -1
}
