import React from 'react'
import SearchInput from './search'
import { contactIcon, downloadIcon } from '../nav-icons'

const TopPanel = ({ host, includeSearch, searchUrl, contactUrl, sections, downloadJmpValue, downloadUrl }) => (
  <div className='nav-panel-top font--center'>
    <ul className='flex flex--space-between' style={{ height: '100%' }}>
      <div className='nav-panel-top__links flex flex--center-y font--center'>
        { sections.map((section, i) =>
          <a
            key={ i }
            className='nav-panel-top__a'
            target={ section.text === 'Open Source' && host === ''
              ? '_self'
              : '_blank'
            }
            href={ section.href }>
            <li className='nav-panel-top__li'>{ section.text }</li>
          </a>
        ) }
      </div>

      <div className='flex flex--center-y'>
        <a href={ contactUrl }>
          <button
            className='flex flex--center-all flex--wrap nav-panel-top__contact'
            style={ includeSearch ? {} : { marginRight: '15px' } }>
            { contactIcon }
          </button>
        </a>

        { includeSearch && <SearchInput searchUrl={ searchUrl } /> }

        <a
          className='nav-panel-top__a'
          href={ `${host}${downloadUrl}${downloadJmpValue === '' ? '' : `?jmp=${downloadJmpValue}`}` }
          target={ host === '' ? '_self' : '_blank' }>
          <button className={`
            btn-small btn-fill btn-fill--light-green
            margin--left-xs nav-panel-top__download
          `}>
            <span style={{ verticalAlign: 'middle' }}>Download</span>
            { downloadIcon }
          </button>
        </a>
      </div>
    </ul>
  </div>
)

const { string, bool, array } = React.PropTypes

TopPanel.propTypes = {
  includeSearch: bool,
  searchUrl: string,
  contactUrl: string,
  sections: array,
  host: string.isRequired,
  downloadUrl: string,
  downloadJmpValue: string
}

TopPanel.defaultProps = {
  includeSearch: true,
  searchUrl: '/search?search=',
  contactUrl: '/contact?jmp=nav',
  downloadUrl: '/download-center',
  downloadJmpValue: 'nav'
}

export default TopPanel
