import React from 'react'
import { VelocityComponent } from 'velocity-react'
import { searchIcon } from '../nav-icons'

export default class SearchInput extends React.Component {
  constructor (props) {
    super(props)
    this.state = { isOpen: false }
    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuint'
    }

    this.setState = this.setState.bind(this)
    this.onBtnPress = this.onBtnPress.bind(this)
    this.toggle = this.toggle.bind(this)
  }

  componentDidMount () {
    this.links = document.querySelector('.nav-panel-top__links')
  }

  onSearch () {
    const value = encodeURIComponent(this.refs.searchInput.value)
    window.location.href = `${this.props.searchUrl}${value}`
  }

  onBtnPress (e) {
    e.preventDefault()
    e.stopPropagation()

    if (!this.state.isOpen) {
      this.refs.searchInput.focus()
      this.toggle(true)
    } else if (!this.refs.searchInput.value) {
      this.toggle(false)
    } else {
      this.onSearch()
    }
  }

  toggle (isOpen) {
    this.setState({ isOpen })
    this.links.classList.toggle('nav-panel-top__links--hidden', isOpen)
  }

  render () {
    const { isOpen } = this.state

    return (
      <span className='flex flex--wrap'>
        <VelocityComponent
          { ...this.velocityConfig }
          animation={ isOpen
            ? { marginRight: '-35px', opacity: 1 }
            : { marginRight: '-210px', opacity: 0 }
          }>
          <input
            className='input nav-panel-top__input'
            onBlur={ () => window.setTimeout(() => this.toggle(false), 50) }
            onKeyUp={ e => e.keyCode === 13 && this.onSearch() }
            ref='searchInput'
            placeholder='search' />
        </VelocityComponent>
        <VelocityComponent
          { ...this.velocityConfig }
          animation={ isOpen ? { scale: 0.8 } : { scale: 1 } }>
          <button
            className='flex flex--center-all flex--wrap nav-panel-top__search'
            onClick={ this.onBtnPress }
            onTouchStart={ this.onBtnPress }
          >{ searchIcon }</button>
        </VelocityComponent>
      </span>
    )
  }
}

const { string } = React.PropTypes

SearchInput.propTypes = {
  searchUrl: string
}
